@@ -9,9 +9,9 @@ require_relative 'prime'
 # --  Tests ----
 class PrinterGraphTest < TestCase
   def setup
+    super
     # WALL_TIME so we can use sleep in our test and get same measurements on linux and windows
-    RubyProf::measure_mode = RubyProf::WALL_TIME
-    @result = RubyProf.profile do
+    @result = RubyProf::Profile.profile(measure_mode: RubyProf::WALL_TIME) do
       run_primes(1000, 5000)
     end
   end
